@@ -4,54 +4,48 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
          values=c("data", "count", "prop", "sum", "mean", "sd", "min",
                   "median", "max"),
 
-         color.fill=getOption("color.fill.pt"),
-         color.stroke=getOption("color.stroke.pt"),
-         color.bg=getOption("color.bg"),
-         color.grid=getOption("color.grid"),
-         color.box=getOption("color.box"),
+         fill=getOption("fill.pt"),
+         stroke=getOption("stroke.pt"),
+         bg=getOption("bg"),
+         grid=getOption("grid"),
+         box=getOption("box"),
+         segment=getOption("fill.pt"),
+         color=NULL, trans=NULL,
 
-         color=NULL, color.trans=NULL,
-
-         cex.axis=0.76, color.axis="gray30", xy.ticks=TRUE,
+         cex.axis=0.76, axes="gray30", xy.ticks=TRUE,
          xlab=NULL, ylab=NULL, main=NULL, sub=NULL,
-         value.labels=NULL, rotate.values=0, offset=0.5,
-         proportion=FALSE,
-
-         run.chart=FALSE, line.width=2, color.area=FALSE, 
-         center.line=c("default", "mean", "median", "zero", "off"),
-         show.runs=FALSE,
+         value.labels=NULL, label.max=20,
+         rotate.values=0, offset=0.5, proportion=FALSE,
 
          size=NULL, shape="circle", means=TRUE,
          sort.yx=FALSE,
          segments.y=FALSE, segments.x=FALSE,
 
+         bubble.scale=0.25, bubble.power=0.6, bubble.text=NULL,
+         low.color=NULL, hi.color=NULL,
+
          smooth=FALSE, smooth.points=100, smooth.trans=0.25,
          smooth.bins=128,
 
-         bubble.scale=0.25, bubble.power=0.6, bubble.text=NULL,
-         color.low=NULL, color.hi=NULL,
+         fit=NULL, stroke.fit=getOption("stroke.bar"),
+         se.fit=0,
 
-         fit.line=NULL, color.fit.line="gray55",
-
-         ellipse=FALSE, color.ellipse=getOption("color.stroke.pt"),
-         color.fill.ellipse=getOption("color.fill.ellipse"),
+         ellipse=FALSE, stroke.ellipse=getOption("stroke.pt"),
+         fill.ellipse=getOption("fill.ellipse"),
 
          method="overplot", pt.reg="circle", pt.out="circle",
-         color.out30="firebrick2", color.out15="firebrick4", new=TRUE,
+         out30="firebrick2", out15="firebrick4", new=TRUE,
          boxplot=FALSE,
 
-         bar=FALSE,
-         breaks="Sturges", bin.start=NULL, bin.width=NULL, bin.end=NULL,
-         cumul=c("off", "on", "both"), hist.counts=FALSE,
-         color.reg="snow2",
+         line.chart=FALSE, line.width=2, area=FALSE, 
+         center.line=c("default", "mean", "median", "zero", "off"),
+         show.runs=FALSE, stack=FALSE,
 
-         beside=FALSE, horiz=FALSE,
-         over.grid=FALSE, addtop=0.05, gap=NULL, count.labels=NULL,
-         legend.title=NULL, legend.loc="right.margin", legend.labels=NULL,
-         legend.horiz=FALSE,
+         breaks="Sturges", bin.start=NULL, bin.width=NULL, bin.end=NULL,
+         cumul=FALSE,
 
          digits.d=NULL, quiet=getOption("quiet"),
-         pdf.file=NULL, pdf.width=NULL, pdf.height=NULL,
+         width=NULL, height=NULL, pdf.file=NULL, 
          fun.call=NULL, ...) {
 
   # ------
@@ -59,9 +53,18 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
   
   if (is.null(fun.call)) fun.call <- match.call()
    
+  # limit actual argument to alternatives, perhaps abbreviated
   values <- match.arg(values)
   center.line <- match.arg(center.line)
-  cumul <- match.arg(cumul)
+
+  df.name <- deparse(substitute(data))
+  options(dname = df.name)
+
+  # if a tibble convert to data frame
+  # data.frame is already #3 in class(data), so no char --> factor conversion 
+  if (class(data)[1] == "tbl_df") {
+    data <- as.data.frame(data, stringsAsFactors=TRUE)
+  }
 
   # missing function only reliable if arg not modified, so capture 
   x.miss <- ifelse (missing(x), TRUE, FALSE)
@@ -71,15 +74,24 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
   seg.y.miss <- ifelse (missing(segments.y), TRUE, FALSE)  # for Cleveland plot
   seg.x.miss <- ifelse (missing(segments.x), TRUE, FALSE)
   sort.yx.miss <- ifelse (missing(sort.yx), TRUE, FALSE)
-  col.grid.miss <- ifelse (missing(color.grid), TRUE, FALSE)
+  col.grid.miss <- ifelse (missing(grid), TRUE, FALSE)
+  
+  date.ts <- FALSE  # default is not a time series
+  freq.poly <- FALSE  # default is not a frequency polygon
 
-  if (color.grid == "on") color.grid <- getOption("color.grid") # for Cleveland
-  if (is.logical(color.area))
-    color.area <- ifelse (color.area, getOption("color.fill.pt"), "off")
- 
-  # any run.chart parameter activates a run.chart
-  if (show.runs)
-    run.chart <- TRUE
+  if (grid == "on") grid <- getOption("grid") # for Cleveland
+
+  if (se.fit[1] > 0) if (is.null(fit)) fit <- TRUE
+
+  if (show.runs) line.chart <- TRUE
+
+  # area
+  if (stack) if (missing(area)) area <- TRUE  # stack default
+  if (is.logical(area))
+    area <- ifelse (area, getOption("fill.pt"), "off")
+  if (area != "off") if (missing(stack)) stack <- TRUE
+
+  if (values != "data") if (is.null(trans)) trans <- 0
 
   # any bin parameter activates bins
   if (!missing(breaks)  ||  !missing(bin.start)  ||  !missing(bin.width)  ||
@@ -87,18 +99,8 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
     values <- "count"
 
   object <- "default"
-  if (bar) {
-    object <- "bar"
-    if (values == "data") values <- "count"
-
-    if (values.miss) values <- "count"  # default topic for bars
-    if (values == "data") {
-      cat("\n"); stop(call.=FALSE, "\n","------\n",
-      "Bars do not apply to data, only to count, mean, etc.\n\n")
-    }
-    if (missing(color.fill)) color.fill <- getOption("color.fill.bar")
-  }
-  if (run.chart) object <- "both"
+  
+  if (line.chart) object <- "both"
 
   # any bubble parameter activates a bubble plot
   if (!missing(bubble.scale) || !missing(bubble.scale) || !missing(bubble.text)) {
@@ -107,35 +109,36 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
 
   # any ellipse parameter actives an ellipse
   if (missing(ellipse)) 
-    if (!missing(color.ellipse) || !missing(color.fill.ellipse))
+    if (!missing(stroke.ellipse) || !missing(fill.ellipse))
       ellipse <- TRUE
 
-  if (is.null(fit.line)) fit.ln <- "off"
-  if (is.logical(fit.line))
-    fit.ln <- ifelse (fit.line, "loess", "off")
-  if (is.character(fit.line)) {
-    if (!(fit.line %in% c("loess", "ls", "off"))) {
+  if (is.null(fit)) fit.ln <- "off"
+  if (is.logical(fit))
+    fit.ln <- ifelse (fit, "loess", "off")
+  if (is.character(fit)) {
+    if (!(fit %in% c("loess", "ls", "off"))) {
       cat("\n"); stop(call.=FALSE, "\n","------\n",
-        "fit.line applies only for  loess  or  ls  (least squares)\n\n")
+        "fit applies only for  loess  or  ls  (least squares)\n\n")
     }
-    fit.ln <- fit.line  # fit.ln passed to .plt.main
+    fit.ln <- fit  # fit.ln passed to .plt.main
   }
   
-  # "off" substitutes for official arg value of "transparent"
-  for (i in 1:length(color.fill))
-    if (color.fill[i] == "off") color.fill[i] <- "transparent"
-  for (i in 1:length(color.stroke))
-    if (color.stroke[i] == "off") color.stroke[i] <- "transparent"
-  if (color.bg == "off") color.bg <- "transparent"
-  if (color.grid == "off" ) color.grid <- "transparent"
-  if (color.box == "off") color.box <- "transparent"
-  if (color.fill.ellipse == "off") color.fill.ellipse <- "transparent"
-  if (!is.null(color.area)) if (color.area == "off") color.area <- "transparent"
+  # "off" substitutes for official value of "transparent"
+  for (i in 1:length(fill))
+    if (fill[i] == "off") fill[i] <- "transparent"
+  for (i in 1:length(stroke))
+    if (stroke[i] == "off") stroke[i] <- "transparent"
+  if (bg == "off") bg <- "transparent"
+  if (grid == "off" ) grid <- "transparent"
+  if (box == "off") box <- "transparent"
+  if (stroke.ellipse == "off") stroke.ellipse <- "transparent"
+  if (fill.ellipse == "off") fill.ellipse <- "transparent"
+  if (area == "off") area <- "transparent"
 
   # populate color parameters
   if (!is.null(color)) {
-    color.stroke <- color
-    color.fill <- color
+    stroke <- color
+    fill <- color
   }
 
   if (is.logical(ellipse)) if (ellipse) ellipse <- 0.95
@@ -182,22 +185,22 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
       if (!(pt.out %in% c(21:25))) bad.shape <- pt.out
 
     if (!is.null(bad.shape)) {
-        message("\nValid shapes")
-        message("------------")
-        for (j in 1:length(shapes)) message(shapes[j])
-        message("all uppercase and lowercase letters")
-        message("all digits")
-        message("+ * # % ! = - & $ ? | < > @")
-        cat("\n")
-        stop(call.=FALSE, "\n","------\n",
-        "Not a valid shape: ", bad.shape, "\n\n")
+      message("\nValid shapes")
+      message("------------")
+      for (j in 1:length(shapes)) message(shapes[j])
+      message("all uppercase and lowercase letters")
+      message("all digits")
+      message("+ * # % ! = - & $ ? | < > @")
+      cat("\n")
+      stop(call.=FALSE, "\n","------\n",
+      "Not a valid shape: ", bad.shape, "\n\n")
     }
   }
     
 
   # ------
   # see if dated or inconsistent parameter values
-  .plt.zbad(x.miss, y.miss, values, method, breaks, bin.start, bar, ...)
+  .plt.zbad(x.miss, y.miss, values, method, breaks, bin.start, ...)
 
 
   # ------
@@ -207,11 +210,9 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
   x.name <- deparse(substitute(x))
   options(xname = x.name)
 
-  # get data frame name
-  df.name <- deparse(substitute(data))
-  options(dname = df.name)
-
   # get data to be analyzed into data.x data frame
+  
+  # process row.names if specified
   if (deparse(substitute(x)) == "row.names") {
     # retain order of row names, otherwise will be alphabetical
     data.x <- data.frame(factor(row.names(data), levels=row.names(data)))
@@ -219,8 +220,7 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
     cat.x <- TRUE
   }
 
-  else {
-    if (!exists(x.name, where=.GlobalEnv)) {  # x not in global env, in df
+  else if (!exists(x.name, where=.GlobalEnv)) {  # x not in global env, in df
       .nodf(df.name)  # check to see if data frame container exists
       .xcheck(x.name, df.name, data)  # var in df?, vars lists not checked
       all.vars <- as.list(seq_along(data))  # even if only a single var
@@ -228,52 +228,84 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
       x.col <- eval(substitute(x), envir=all.vars)  # col num of selected vars
       if (!("list" %in% class(data))) {
         data.x <- data[, x.col]
-        if (length(x.col) == 1) {  # x is 1 var
-          data.x <- data.frame(data.x)
-          names(data.x) <- x.name
-        }
-      }
-      else {  # class of data is "list"
+        data.x <- data.frame(data.x)
+     }      
+     else {  # class of data is "list"
         data.x <- data.frame(data[[x.col]])
-        names(data.x) <- x.name
       }
-    }
+      names(data.x) <- names(all.vars)[x.col]
 
-    else {  # x is in the global environment (vector or data frame)
-      if (is.data.frame(x)) {  # x a data frame
+    }  # end x not in global
+
+    # x is in the global environment (vector or data frame)
+    # can only access x directly if it is not in a data frame
+ 
+    else if (is.data.frame(x)) {
+        # x a data frame
         cat("\n"); stop(call.=FALSE, "\n","------\n",
           "Need to specify variables for analysis,\n",
           "not a full data frame\n\n")
     }
-      else {  # x a vector in global
+      
+    else if (is.ts(x)) {  #  time series in global
+        data.x <- data.frame(.ts.dates(x))  # just the dates for x var
+        names(data.x) <- "date"
+        # x.col <- 1  # just put dates in data.x
+        # n.x_var <- 1  # number of x-variables
+        date.ts <- TRUE
+        if (is.null(xlab)) xlab <- ""  # unless specified, drop the axis label
+
+       nc <- ifelse (is.matrix(x), ncol(x), 1)
+        if (nc == 1)
+          y.call <- x
+        else {
+          y.call <- x[,1]
+          if (nc > 1) for (i in 2:nc) y.call <- cbind(y.call, x[,i])
+        }
+        y.call <- data.frame(y.call)
+        y.col <- ncol(y.call)
+        cat.y <- FALSE
+        if (nc == 1) {
+          names(y.call) <- x.name
+          y.name <- x.name
+        }
+        else
+          names(y.call) <- colnames(x)
+
+    y.name <- deparse(substitute(x))
+    options(yname = y.name)
+    }
+      
+      else {  # x a not ts vector in global
         if (!is.function(x))
-          data.x <- data.frame(x)  # x is 1 var
+          data.x <- data.frame(x)  # x is 1 var, including a ts
         else
           data.x <- data.frame(eval(substitute(data$x)))  # x is 1 var
         names(data.x) <- x.name
       }
-    }
-  }
-
-  n.x_var <- ncol(data.x)  # number of x-variables
+      
+      n.x_var <- ncol(data.x)  # number of x-variables
+      x.call <- data.x
+      
+    # end get data.x
+    
 
   # get data.x data to be analyzed into x.call, except for BPFM
   BPFM <- FALSE
 
   # just one x variable for now, a vector of cat or num values
   if (n.x_var == 1) {
-    x.call <- data.x[,1]
-
-    if (!is.ts(x.call)) {
-      nu <- length(unique(na.omit(x.call)))
-      num.cat.x <- .is.num.cat(x.call, n.cat)
+    date.ts <- ifelse (.is.date(x.call[,1]), TRUE, FALSE) 
+    if (!date.ts) {
+      nu <- length(unique(na.omit(x.call[,1])))
+      num.cat.x <- .is.num.cat(x.call[,1], n.cat)
     }
-    else {
-      nu <- length(unique(x.call))
+    else {  # process ts
+      nu <- length(unique(x.call[,1]))
       num.cat.x <- FALSE
     }
 
-    if (!num.cat.x && is.integer(x.call) && !is.ts(x.call) && nu<= n.cat) {
+    if (!num.cat.x && is.integer(x.call[,1]) && !date.ts && nu<= n.cat) {
       cat("\n")
       cat(">>> ", x.name, " has only only ", nu, " unique ",
           "integer values, but not equally spaced,\n",
@@ -283,7 +315,7 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
     }
 
     if (num.cat.x && !quiet) .ncat("Plot", x.name, nu, n.cat)
-    cat.x <- ifelse (num.cat.x || is.factor(x.call), TRUE, FALSE)
+    cat.x <- ifelse (num.cat.x || is.factor(x.call[,1]), TRUE, FALSE)
 
     if (cat.x  &&  object == "both") {
       cat("\n"); stop(call.=FALSE, "\n","------\n",
@@ -291,7 +323,6 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
         x.name, " is a categorical variable\n\n")
     }
   }
-
   else {  # more than one x-variable
     # no y, see if eligible for BPFM where all selected vars are cat
     # multiple lines of a continuous x-variable also can occur
@@ -313,29 +344,38 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
       cat.x <- TRUE
       BPFM <- TRUE
     }
+    
     # if here already numeric, cat can be one-var or many x for a BPFM
-    else {  # all to numeric, NA if char, internal code if factor
-      x.call <- data.matrix(data.x, rownames.force=FALSE)
+    # all to numeric, NA if char, internal code if factor
+    # if a mts, data.matrix does nothing as is already a matrix
+    else {
+      # x.call <- data.frame(data.x)
+      # x.call <- data.matrix(data.x, rownames.force=FALSE)
       cat.x <- FALSE
     }
   }  # end more than 1 x-variable
  
   
   if (!BPFM)
-    n.rows <- ifelse (is.matrix(x.call), nrow(x.call), length(x.call))
+    n.rows <- ifelse (is.matrix(x.call[,1]), nrow(x.call[,1]), length(x.call[,1]))
   else
-    n.rows <- length(data.x)
+    n.rows <- nrow(data.x)
+    #n.rows <- length(data.x)
 
 
   # smooth default
   if (n.rows > 2499) if (missing(smooth)) smooth <- TRUE
-  if (smooth) if (missing(color.grid)) color.grid <- "transparent"
+  if (smooth) if (missing(grid)) grid <- "transparent"
+
+  if(date.ts) {
+    object <- "both"
+  }
 
 
   # evaluate y
   #-----------
-  if (!missing(y)) {
-    # get actual variable name before potential call of data$x
+  if (!y.miss) {
+    # get actual variable name before potential call of data$y
     y.name <- deparse(substitute(y))
     options(yname = y.name)
 
@@ -344,31 +384,30 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
       y.call <- factor(row.names(data), levels=row.names(data))
       if (is.null(ylab)) ylab <- ""  # unless specified, drop the axis label
       cat.y <- TRUE
+      data.y <- data.frame(y.call)
     }
-
-    else {
-      if (!exists(y.name, where=.GlobalEnv)) {  # y not in global env, in df
+      
+    else if (!exists(y.name, where=.GlobalEnv)) {  # y not in global env, in df
         .nodf(df.name)  # check to see if data frame container exists
         .xcheck(y.name, df.name, data)  # var in df?, vars lists not checked
         all.vars <- as.list(seq_along(data))  # even if only a single var
         names(all.vars) <- names(data)  # all data in data frame
         y.col <- eval(substitute(y), envir=all.vars)  # col num selected vars
-        if (!("list" %in% class(data))) {
+       if (!("list" %in% class(data))) {
           data.y <- data[, y.col]
-          if (length(y.col) == 1) {  # y is 1 var
-            data.y <- data.frame(data.y)
-            names(data.y) <- y.name
-          }
-        }
-        else {  # class of data is "list"
+          data.y <- data.frame(data.y)
+       }      
+       else {  # class of data is "list"
           data.y <- data.frame(data[[y.col]])
-          names(data.y) <- y.name
         }
-      }
+        names(data.y) <- names(all.vars)[y.col]        
+      }  # end global y
 
-      else { # y is in the global environment (vector or data frame)
-        if (is.data.frame(y))  # y a data frame
+      else if (is.data.frame(y)){ # y is in the global env (vector or data frame)
+          # y a data frame
           data.y <- y
+       }
+       
         else {  # y a vector in global
           if (!is.function(y))
             data.y <- data.frame(y)  # y is 1 var
@@ -376,15 +415,19 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
             data.y <- data.frame(eval(substitute(data$y)))  # y is 1 var
           names(data.y) <- y.name
         }
-      }
 
-      if (ncol(data.y) == 1) {
-        y.call <- data.y[,1]
+      n.y_var <- ncol(data.y)  # number of y-variables
+      y.call <- data.y
+    # end get data.y
+ 
+
+      if (ncol(y.call) == 1) { # y is one variable
+        # y.call <- data.y[,1]
 
         nu <- length(unique(na.omit(y.call)))
-        num.cat.y <- .is.num.cat(y.call, n.cat)
+        num.cat.y <- .is.num.cat(y.call[,1], n.cat)
 
-        if (!num.cat.y && is.integer(y.call) && nu <= n.cat) {
+        if (!num.cat.y && is.integer(y.call[,1]) && nu <= n.cat) {
           cat("\n")
           cat(">>> ", y.name, " has only only ", nu, " unique ",
               "integer values, but not equally spaced,\n",
@@ -394,22 +437,23 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
         }
 
         if (num.cat.y && !quiet) .ncat("Plot", y.name, nu, n.cat)
-        cat.y <- ifelse (num.cat.y || is.factor(y.call), TRUE, FALSE)
+        cat.y <- ifelse (num.cat.y || is.factor(y.call[,1]), TRUE, FALSE)
       }
+      
       else {  # 2 or more y vars
         cat.y <- FALSE  #  multiple y-vars must be numerical
         if (missing(ylab)) ylab <- ""  # use legend instead
-        y.call <- data.matrix(data.y, rownames.force=FALSE)
+        y.call <- data.frame(data.y)
+        # y.call <- data.matrix(data.y, rownames.force=FALSE)
       }
-    }
-  }
+  }  # end y not missing
+  
   else { # missing y
-    y.call <- NULL
-    if (bar && missing(color.fill))
-      color.fill <- getOption("color.fill.bar")
-  }
+    if (!date.ts) y.call <- NULL
 
-    if (cat.x  &&  run.chart) {
+  }  # end missing y
+
+    if (cat.x  &&  line.chart) {
       cat("\n"); stop(call.=FALSE, "\n","------\n",
         "Run chart only applies to a numerical variable\n\n")
     }
@@ -495,40 +539,27 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
     if (missing(bubble.text)) bubble.text <- TRUE
 
   # -----------  x, y, by and size variables established ------------
+  # -----------------------------------------------------------------
 
   
   # --------
   # manage regular-R or PDF graphics window size
-  
-  if (is.null(y.call)  &&  !BPFM  &&  method != "stack" &&  values == "data"
-      && !(object %in% c("both", "bar"))  &&  !is.ts(x.call))
-    plt.h <- ifelse (is.null(main), 2.5, 3.1)  # narrow for 1-D plot
-  else
-    plt.h <- 7
+  if (is.null(height)) { 
+    if (is.null(y.call)  &&  !BPFM  &&  method != "stack"  &&  values == "data"
+        &&  object != "both"  &&  !.is.date(x.call))
+      height <- ifelse (is.null(main), 2.5, 3.1)  # narrow for 1-D dotplot
+    else
+      height <- 4.5
 
-  # BPFM, more than 7 variables, make plot extra long
-  if (BPFM)
-    plt.h <- plt.h + ((ncol(data.x) - 7) * 0.5)
+    if (BPFM)  # more than 7 variables, make plot extra long
+      height <- height + ((ncol(data.x) - 7) * 0.5)
+  }
 
-  if (is.null(pdf.file)) {
-    regR <- TRUE
-    if (class(getOption("device")) == "character")
-      if (getOption("device") == "RStudioGD") regR <- FALSE
-    if (!is.null(options()$knitr.in.progress)) regR <- FALSE
-    if (regR) {  # regular R run
-      if (by.miss)  # set up graphics system to manage
-        .graphwin(1, d.h=plt.h)
-      else  # there is a by variable
-        .graphwin(d.w=pdf.width)  # add width to default of 4.5 for legend
-    }
-  }
-  else  {  # pdf file
-    if (is.null(pdf.width)) pdf.width <- 4.5
-    if (!missing(by.call)) pdf.width <- pdf.width + 0.6
-    if (is.null(pdf.height)) pdf.height <- plt.h
-    # windows puts a blank first page without the onefile=FALSE
-    pdf(file=pdf.file, width=pdf.width, height=pdf.height, onefile=FALSE)
-  }
+  if (is.null(width)) width <- 4.5
+  if (!by.miss) width <- width + .85  # wider plot
+
+  # prepare graphics window, dev or pdf
+  .opendev(pdf.file, width, height)
 
 
   # ------------------------------------------------
@@ -537,24 +568,18 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
   # prep 1-variable bubble plot to call regular scatter plot function
   # y.call to 0
   if (is.null(y.call)  &&  cat.x  &&  n.x_var == 1  &&  values == "data") {
-    y.call <- rep(0, length(x.call))
+    y.call <- data.frame(rep(0, nrow(x.call)))
     cat.y <- FALSE
     if (object == "default") object <- "bubble"
   }
 
-
   # if numeric x is sorted with equal intervals, set as line chart
   # x.call does not exist for BPFM
-  if (!cat.x) if (is.numeric(x.call)  &&  n.rows > 2) {
+  if (!cat.x) if (is.numeric(x.call[,1])  &&  n.rows > 2) {
     if (object == "default") {
-      if (sum(is.na(x.call)) > 0)
-        eq.int <- FALSE  # missing data in x present
-      else {
-        eq.int <- TRUE
-        if (is.matrix(x.call))
-          d.x <- diff(x.call[,1])  # only look at first x-variable
-        else
-          d.x <- diff(x.call)  # only look at first x-variable
+      eq.int <- ifelse (sum(is.na(x.call[,1])) > 0, FALSE, TRUE)
+      if (eq.int) {
+        d.x <- diff(x.call[,1])  # only look at first x-variable
         for (i in 2:(length(d.x)))
           if ((abs(d.x[i-1] - d.x[i]) > 0.0000000001)) eq.int <- FALSE
         rm(d.x)
@@ -562,13 +587,11 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
 
       if(!is.unsorted(x.call) && eq.int && sum(is.na(y))==0) {
         object <- "both"
-        if (is.null(size)) size <- 0  # by default, just plot a line without the points
+        if (is.null(size)) size <- 0  # by default, just plot a line w/o points
       }
     }
   }
 
-  if (object != "both") if (!BPFM) if (is.ts(x.call)) object <- "both"
-
   # if numeric y is sorted with equal intervals, line chart
   if (is.numeric(y.call)  &&  n.rows > 2) {
     if (object == "default") {
@@ -591,7 +614,7 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
 
   # set point or bubble plot
   if (object == "default") {  # set default
-    if (!missing(y)) {
+    if (!y.miss) {
       object <- "point"
       if (values == "data") if (cat.x && cat.y) object <- "bubble"
     }
@@ -617,63 +640,9 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
     fncl <- gsub(" = ", "=", fncl)
   }
   
-  # histogram or bar chart
-  if (object == "bar"  &&  values %in% c("count", "prop")) {
-
-    if (!cat.x) {  # histogram
-
-      if (values == "prop") proportion <- TRUE
-
-      h <- .hst.main(x.call, color.fill, color.stroke, color.bg, color.grid,
-         color.box, color.reg,
-         over.grid=FALSE, cex.axis, color.axis, rotate.values, offset,
-         breaks, bin.start, bin.width, bin.end, proportion, hist.counts, cumul,
-         xlab, ylab, main, sub, quiet, fun.call=NULL, ...)
-
-      if (!quiet) { # histogram text output
-
-        stats <- .hst.stats(h, length(x.call), fun.call)
-
-        txsug <- stats$txsug
-        txdst <- stats$tx
-
-        bin.width <- stats$bin.width
-        n.bins <- stats$n.bins
-        prop <- stats$prop
-        cum.c <- stats$counts_cum
-        cum.p <- stats$prop_cum
-
-        txotl <- .outliers(data[,i])
-        if (length(txotl)==0) txotl <- "No outliers"
-
-        if (ncol(data) > 1) {  # for a variable range, print the text output
-          class(txsug) <- "out_piece"
-          class(txdst) <- "out_piece"
-          class(txotl) <- "out_piece"
-          output <- list(out_suggest=txsug, out_freq=txdst, out_outliers=txotl)
-          class(output) <- "out_all"
-          print(output)
-        }
-      }
-    }
-
-    else {  # categorical variable, bar chart for values = "count"
-
-      if (values == "prop") proportion <- TRUE
-      .bc.main(x.call, by=y.call,
-        color.fill, color.stroke, color.bg, color.grid, color.box,
-        colors=getOption("colors"),
-        horiz, over.grid, addtop, gap,
-        proportion, xlab, ylab, main, value.labels,
-        cex.axis, color.axis, rotate.values, offset, beside,
-        color.low, color.hi, count.labels,
-        legend.title, legend.loc, legend.labels, legend.horiz,
-        quiet=quiet, ...)
-    }
-  }
 
   # bubble plot frequency matrix (BPFM)
-  else if (ncol(data.x) > 1  &&  y.miss  &&  object == "bubble") {
+  if (ncol(data.x) > 1  &&  y.miss  &&  object == "bubble") {
     # get labels just for subset data matrix
     mylabels <- attr(data, which="variable.labels")
     nm <- names(data.x)
@@ -689,9 +658,9 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
     if (is.null(xlab)) xlab <- ""  # suppress x-axis label if not specified
 
     .dpmat.main(data[,x.col], mylabs, sort.yx,
-      color.fill, color.stroke, color.bg, color.grid, color.trans,
-      shape, color.area, color.box,
-      cex.axis, color.axis, color.low, color.hi,
+      fill, stroke, bg, grid, trans,
+      shape, area, box,
+      cex.axis, axes, low.color, hi.color,
       xy.ticks, xlab, ylab, main, sub, size,
       bubble.scale, bubble.text, bubble.power,
       value.labels, rotate.values, offset, quiet, fun.call, ...)
@@ -701,7 +670,7 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
   else {  # all the other analyses
 
     # line chart prep of x.call and y.call
-    if (y.miss) {  
+    if (y.miss  &&  !date.ts) {  
 
       if (!cat.x) { 
 
@@ -709,30 +678,29 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
           y.call <- x.call
           cat.y <- cat.x
           options(yname = x.name)
-          if (!is.ts(y.call)) {
+          
             options(xname = "Index")
-            if (!is.matrix(x.call)) # xlab <- "Index"
-              x.call <- 1:length(x.call)
-            else {
-              x.call <- 1:nrow(x.call)
-            }
-          }
-          else {  # time series
-            x.call <- ts.dates(y.call)
-          }
+              x.call <- data.frame(1:nrow(x.call))
+              names(x.call) <- "Index"
         }
 
         else if (values %in% c("count", "prop")) {  # frequency polygon
 
-          ssstuff <- .ss.numeric(x.call, digits.d=digits.d, brief=TRUE)
+          ssstuff <- .ss.numeric(x.call[,1], digits.d=digits.d, brief=TRUE)
           txss <- ssstuff$tx  # stats output before reduce data
          
-          h <- .hst.main(x.call, color.fill, color.stroke, color.bg, color.grid,
-             color.box, color.reg,
-             over.grid=FALSE, cex.axis, color.axis, rotate.values, offset,
-             breaks, bin.start, bin.width, bin.end, proportion, hist.counts, cumul,
-             xlab, ylab, main, sub, quiet, fun.call=NULL, do.plot=FALSE, ...) 
+          hist.counts <- FALSE
+          hist.cumul <- ifelse(cumul, "on", "off")
+          reg <- "snow2"  # applies to cumulative histogram
+          h <- .hst.main(x.call[,1], fill, stroke, bg, grid,
+             box, reg,
+             over.grid=FALSE, cex.axis, axes, rotate.values, offset,
+             breaks, bin.start, bin.width, bin.end, proportion, hist.counts,
+             hist.cumul, xlab, ylab, main, sub, quiet, fun.call=NULL,
+             do.plot=FALSE, ...) 
 
+  
+          n.cat <- 0  # not many midpoints, do not want to trigger num.cat
           x.call <- h$mids
           y.call <- h$counts
           if (values == "count")
@@ -743,6 +711,7 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
           }
 
           object <- "both"  # do freq poly as a line chart
+          freq.poly <- TRUE  # need to indicate fill possibility
           center.line <- "off"  # not meaningful here
     
           txsug <- ""
@@ -750,15 +719,15 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
             txsug <- ">>> Suggestions"
 
             fc <- ""
-            if (!grepl("color.area", fncl))
-              fc <- paste(fc, ", color.area=TRUE", sep="")
+            if (!grepl("area", fncl))
+              fc <- paste(fc, ", area=TRUE", sep="")
             if (nzchar(fc)) {
               fc <- paste(fncl, fc, ") ", sep="")
               txsug <- paste(txsug, "\n", fc, sep="")
             }
               
             fc <- ""
-            if (!grepl("size", fncl)  &&  !grepl("color.area", fncl))
+            if (!grepl("size", fncl)  &&  !grepl("area", fncl))
               fc <- paste(fc, ", size=0", sep="")
             if (nzchar(fc)) {
               fc <- gsub(" = ", "=", fc)
@@ -766,7 +735,7 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
               txsug <- paste(txsug, "\n", fc, sep="")
             }
 
-            bw.new <- pretty((x.call[2] - x.call[1]) / 1.5)  # arbitrary value of new bw
+            bw.new <- pretty((x.call[2] - x.call[1]) / 1.5)  # arbitrary new bw
             fc <- ""
             if (!grepl("bin.width", fncl))
               fc <- paste(fc, ", bin.width=", as.character(bw.new[1]), sep="")
@@ -794,8 +763,11 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
           class(output) <- "out_all"
           print(output)
 
-        }
-      }
+          x.call <- data.frame(x.call)
+          y.call <- data.frame(y.call)
+
+        }  # end freq polygon
+      }  # end !cat.x
 
       else {  # cat.x
         # just x variable, so set y.call to plot points for count and prop
@@ -806,11 +778,12 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
           ylab <- paste(ylab, x.name)
           frq <- table(x.call)
           if (values == "prop") frq <- frq / sum(frq)
-          y.call <- as.vector(frq)
+          y.call <- data.frame(as.vector(frq))
           if (is.factor(x.call))  # preserve ordering, will lose order attribute
             x.call <- factor(names(frq), levels=levels(x.call))
           else
             x.call <- factor(names(frq))
+          x.call <- data.frame(x.call)
         }
       }
 
@@ -821,8 +794,7 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
 
       n.cat <- 0
       means <- FALSE
-      if (missing(segments.x)) segments.x <- TRUE
-      if (is.null(color.trans)) color.trans <- 0
+      if (seg.x.miss) segments.x <- TRUE
 
       # do stats console output before reducing data
       if (!quiet) {
@@ -833,7 +805,8 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
           }
           options(yname = x.name)  # reverse order of x and y for .ss.numeric
           options(xname = y.name)
-          stats <- .ss.numeric(y.call, by=x.call, digits.d=digits.d, brief=TRUE)
+          stats <- .ss.numeric(y.call[,1], by=x.call[,1],
+                               digits.d=digits.d, brief=TRUE)
           txout <- stats$tx
           options(xname = x.name)  # reverse back
           options(yname = y.name)
@@ -854,27 +827,27 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
     # set up new x.call and y.call for stats
       if (values == "sum") {
         ylab <- paste("Sum of", y.name)
-        out <- tapply(y.call, x.call, sum, na.rm=TRUE)
+        out <- tapply(y.call[,1], x.call[,1], sum, na.rm=TRUE)
       }
       if (values == "mean") {
         ylab <- paste("Mean of", y.name)
-        out <- tapply(y.call, x.call, mean, na.rm=TRUE)
+        out <- tapply(y.call[,1], x.call[,1], mean, na.rm=TRUE)
       }
       if (values == "sd") {
         ylab <- paste("Standard Deviation of", y.name)
-        out <- tapply(y.call, x.call, sd, na.rm=TRUE)
+        out <- tapply(y.call[,1], x.call[,1], sd, na.rm=TRUE)
       }
       if (values == "min") {
         ylab <- paste("Minimum of", y.name)
-        out <- tapply(y.call, x.call, min, na.rm=TRUE)
+        out <- tapply(y.call[,1], x.call[,1], min, na.rm=TRUE)
       }
       if (values == "median") {
         ylab <- paste("Median of", y.name)
-        out <- tapply(y.call, x.call, median, na.rm=TRUE)
+        out <- tapply(y.call[,1], x.call[,1], median, na.rm=TRUE)
       }
       if (values == "max") {
         ylab <- paste("Maximum of", y.name)
-        out <- tapply(y.call, x.call, max, na.rm=TRUE)
+        out <- tapply(y.call[,1], x.call[,1], max, na.rm=TRUE)
       }
 
       if (is.factor(x.call))  # preserve ordering, will lose order attribute
@@ -890,37 +863,28 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
       }
       y.call <- as.vector(out)
 
-      if (bar) {  # bar chart for stats
-        names(y.call) <- x.call
-
-        .bc.main(y.call, by=NULL,
-          color.fill, color.stroke, color.bg, color.grid, color.box,
-          colors=getOption("colors"),
-          horiz, over.grid, addtop, gap,
-          proportion, xlab, ylab, main, value.labels,
-          cex.axis, color.axis, rotate.values, offset, beside,
-          color.low, color.hi, count.labels,
-          legend.title, legend.loc, legend.labels, legend.horiz,
-          quiet=quiet, ...)
-      }
+      x.call <- data.frame(x.call)
+      y.call <- data.frame(y.call)
     }  # sum, mean, sd, min, median, max
 
 
     # 2-variable scatter plot
     # bubble plot for 1-variable (y.call=0) and 2-variable
     # line chart
-    if (!is.null(y.call)  &&
+    if ((!is.null(y.call) || date.ts) &&
         object %in% c("point", "bubble", "both", "sunflower")) {
 
-      unique.x <- ifelse (length(unique(x.call)) == length(x.call), TRUE, FALSE)
-      unique.y <- ifelse (length(unique(y.call)) == length(y.call), TRUE, FALSE)
+      lx <- length(x.call[,1])
+      ly <- length(y.call[,1])
+      unique.x <- ifelse (length(unique(x.call[,1])) == lx, TRUE, FALSE)
+      unique.y <- ifelse (length(unique(y.call[,1])) == ly, TRUE, FALSE)
 
       if (object == "point"  &&  values == "data"){  # for Cleveland dot plot
         if (!cat.x && cat.y && unique.y) {  # no sort.xy option
           if (seg.y.miss) if (unique.y && cat.y) segments.y <- TRUE
           if (seg.x.miss) if (unique.x && cat.x) segments.x <- TRUE
           if (sort.yx.miss) if (n.x_var <= 2) sort.yx <- TRUE
-          if (col.grid.miss) color.grid <- "transparent"
+          if (col.grid.miss) grid <- "transparent"
         }
       }
 
@@ -935,38 +899,40 @@ function(x, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
             cat("\n"); stop(call.=FALSE, "\n","------\n",
             "Sorting not meaningful for more than two x-variables\n\n")
           }
-        y.call <- factor(y.call, levels=y.call[ord])
+        y.c <- y.call[,1]
+        y.c <- factor(y.c, levels=y.c[ord])
+        y.call[,1] <- y.c
       }
 
       # bigger point for scatterplot of stats
-      if (values != "data"  &&  object == "point"  )
-        if (is.null(size)) size <- 1.75
+      if (values != "data"  &&  object == "point")
+        if (is.null(size)) size <- 2.75
 
       .plt.main(x.call, y.call, by.call, n.cat,
          object, values,
-         color.fill, color.stroke, color.bg, color.grid, color.box,
-         color.trans, color.area,
-         cex.axis, color.axis, xy.ticks,
-         xlab, ylab, main, sub, value.labels, rotate.values, offset,
-         proportion,
+         fill, stroke, bg, grid, box,
+         trans, segment, area,
+         cex.axis, axes, xy.ticks,
+         xlab, ylab, main, sub, value.labels, label.max,
+         rotate.values, offset, proportion,
          size, shape, means, sort.yx, segments.y, segments.x, line.width,
          smooth, smooth.points, smooth.trans, smooth.bins,
-         bubble.scale, bubble.power, bubble.text, color.low, color.hi,
-         fit.ln, color.fit.line,
-         ellipse, color.ellipse, color.fill.ellipse,
-         center.line, show.runs,
-         method, pt.reg, pt.out, color.out30, color.out15,
-         quiet, fun.call, ...)
+         bubble.scale, bubble.power, bubble.text, low.color, hi.color,
+         fit.ln, stroke.fit, se.fit,
+         ellipse, stroke.ellipse, fill.ellipse,
+         center.line, show.runs, stack,
+         method, pt.reg, pt.out, out30, out15,
+         freq.poly, quiet, fun.call, ...)
     }
 
     # 1-D traditional scatter plot (not bubble plot)
     else if (!cat.x  &&  is.null(y.call)  &&  values == "data") {
 
-      .dp.main(x.call, by.call, size,
-         color.fill, color.stroke, color.bg, color.grid, color.trans,
-         shape, cex.axis, color.axis, xlab, main, sub,
+      .dp.main(x.call[,1], by.call, size,
+         fill, stroke, bg, grid, trans,
+         shape, cex.axis, axes, xlab, main, sub,
          rotate.values, offset, method, pt.reg, pt.out,
-         color.out30, color.out15, boxplot, quiet, new, 
+         out30, out15, boxplot, quiet, new, 
          vertical=FALSE, fun.call, ...)
 
         # R Markdown
